/*
 * Copyright 2018 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.car.settings.bluetooth;

import android.bluetooth.BluetoothAdapter;
import android.car.drivingstate.CarUxRestrictions;
import android.content.Context;

import androidx.annotation.VisibleForTesting;
import androidx.preference.Preference;

import com.android.car.settings.R;
import com.android.car.settings.common.FragmentController;

/**
 * Displays the Bluetooth MAC address of the vehicle.
 */
public class BluetoothAddressPreferenceController extends
        BluetoothPreferenceController<Preference> {

    private final BluetoothAdapter mBluetoothAdapter;

    public BluetoothAddressPreferenceController(Context context, String preferenceKey,
            FragmentController fragmentController, CarUxRestrictions uxRestrictions) {
        this(context, preferenceKey, fragmentController, uxRestrictions,
                BluetoothAdapter.getDefaultAdapter());
    }

    @VisibleForTesting
    BluetoothAddressPreferenceController(Context context, String preferenceKey,
            FragmentController fragmentController, CarUxRestrictions uxRestrictions,
            BluetoothAdapter bluetoothAdapter) {
        super(context, preferenceKey, fragmentController, uxRestrictions);
        mBluetoothAdapter = bluetoothAdapter;
    }

    @Override
    protected Class<Preference> getPreferenceType() {
        return Preference.class;
    }

    @Override
    protected void updateState(Preference preference) {
        String address = mBluetoothAdapter.getAddress();
        String formattedAddress = getContext().getString(R.string.bluetooth_vehicle_mac_address,
                address);
        preference.setSummary(formattedAddress);
    }
}
